# Tutorials

For a quick introduction to the basics of ZabbixCI, please check out our [quickstart](quickstart.md) tutorial. This will guide you through the first steps in getting to know ZabbixCI.

# Community guides
We are grateful for the community around Zabbix and ZabbixCI for any contributions about how you use ZabbixCI. If you have any content that you would like to share, drop us a message in the [discussions](https://github.com/retigra/ZabbixCI/discussions) or submit a PR with your addition.

## Automate and Centralize Zabbix Templates with ZabbixCI
This video by [@mcbrineellis](https://www.github.com/mcbrineellis) goes into setting up two Zabbix instances and synchronizing templates between the two using ZabbixCI. Connor also goes into using gitlab to merge new templates from `dev` to `prod` git branches.

Click the thumbnail to watch the video:

| [![Automate and Centralize Zabbix Templates with ZabbixCI](https://img.youtube.com/vi/FSdetMaVXP0/default.jpg)](https://youtu.be/FSdetMaVXP0) | [***Automate and Centralize Zabbix Templates with ZabbixCI*** <br> youtube.com](https://youtu.be/FSdetMaVXP0) |
| --- | :--- |




